pub enum RaftEvent {
Show 17 variants
ReceiveVoteRequest(VoteRequest, MaybeCloneOneshotSender<Result<VoteResponse, Status>>),
ClusterConf(MetadataRequest, MaybeCloneOneshotSender<Result<ClusterMembership, Status>>),
ClusterConfUpdate(ClusterConfChangeRequest, MaybeCloneOneshotSender<Result<ClusterConfUpdateResponse, Status>>),
AppendEntries(AppendEntriesRequest, MaybeCloneOneshotSender<Result<AppendEntriesResponse, Status>>),
InstallSnapshotChunk(Box<Streaming<SnapshotChunk>>, MaybeCloneOneshotSender<Result<SnapshotResponse, Status>>),
StreamSnapshot(Box<Streaming<SnapshotAck>>, StreamResponseSender),
JoinCluster(JoinRequest, MaybeCloneOneshotSender<Result<JoinResponse, Status>>),
DiscoverLeader(LeaderDiscoveryRequest, MaybeCloneOneshotSender<Result<LeaderDiscoveryResponse, Status>>),
TriggerSnapshotPush {
peer_id: u32,
},
CreateSnapshotEvent,
LogPurgeCompleted(LogId),
SnapshotCreated(Result<(SnapshotMetadata, PathBuf)>),
PromoteReadyLearners,
StepDownSelfRemoved,
MembershipApplied,
FatalError {
source: String,
error: String,
},
ApplyCompleted {
last_index: u64,
results: Vec<ApplyResult>,
},
}Variants
ReceiveVoteRequest(VoteRequest, MaybeCloneOneshotSender<Result<VoteResponse, Status>>)
ClusterConf(MetadataRequest, MaybeCloneOneshotSender<Result<ClusterMembership, Status>>)
ClusterConfUpdate(ClusterConfChangeRequest, MaybeCloneOneshotSender<Result<ClusterConfUpdateResponse, Status>>)
AppendEntries(AppendEntriesRequest, MaybeCloneOneshotSender<Result<AppendEntriesResponse, Status>>)
InstallSnapshotChunk(Box<Streaming<SnapshotChunk>>, MaybeCloneOneshotSender<Result<SnapshotResponse, Status>>)
StreamSnapshot(Box<Streaming<SnapshotAck>>, StreamResponseSender)
JoinCluster(JoinRequest, MaybeCloneOneshotSender<Result<JoinResponse, Status>>)
DiscoverLeader(LeaderDiscoveryRequest, MaybeCloneOneshotSender<Result<LeaderDiscoveryResponse, Status>>)
TriggerSnapshotPush
CreateSnapshotEvent
LogPurgeCompleted(LogId)
SnapshotCreated(Result<(SnapshotMetadata, PathBuf)>)
PromoteReadyLearners
StepDownSelfRemoved
Node removed itself from cluster membership Leader must step down immediately after self-removal per Raft protocol
MembershipApplied
Membership change has been applied to state Leader should refresh cluster metadata cache
FatalError
State machine apply failed - node must shutdown. Conservative: treat all SM errors as fatal (future: distinguish fatal vs application errors).
ApplyCompleted
State machine apply completed Sent by CommitHandler after applying entries to state machine Contains results for each applied entry (e.g., CAS success/failure)