Module storage

Module storage 

Structs

ApplyResult
Result of applying a single log entry to the state machine
BufferedRaftLog
High-performance buffered Raft log with event-driven architecture
ScanResult
All (key, value) pairs returned by a prefix scan, plus the revision anchor.

Enums

IOTask
IO tasks for the dedicated raft-io thread.

Traits

Lease
Lease management interface for key expiration.
LogStore
MetaStore
Metadata storage operations
StateMachine
State machine trait for Raft consensus
StorageEngine
High-performance storage abstraction for Raft consensus